==> linuxconf-ldapconf-0.20.src.tar.gz: linuxconf-ldapconf-0.20/ldapconf.pm <==
/* _dict.cc 02/07/1999 14.11.24 */
/* browse.tlcc 18/10/2002 00.14.20 */
/* fields.cc 19/08/2002 16.09.52 */
PUBLIC FIELD_DEF::FIELD_DEF (void);
PUBLIC int FIELD_DEF::edit (void);
PUBLIC void FIELD_DEF::loadval (CONFDB *c_data, const char *key);
PUBLIC void FIELD_DEF::saveval (CONFDB *c_data, const char *key);
PUBLIC void FIELD_DEF::delval (CONFDB *c_data, const char *key);
PUBLIC FIELD_DEF *FIELD_DEFS::getitem (int no)const;
PUBLIC void FIELD_DEFS::loadval (CONFDB *c_data, const char *key);
PUBLIC void FIELD_DEFS::saveval (CONFDB *c_data, const char *key);
PUBLIC void FIELD_DEFS::delval (CONFDB *c_data, const char *key);
PUBLIC FIELD_DEFS::FIELD_DEFS (void);
PUBLIC FIELD_DEFS::FIELD_DEFS (CONFDB *formconfig);
PUBLIC FIELD_DEFS::FIELD_DEFS (CONFIG_FILE *formfile);
PUBLIC FIELD_DEFS::FIELD_DEFS (const char *filename);
PUBLIC int FIELD_DEFS::read (void);
PUBLIC int FIELD_DEFS::write (void);
PUBLIC int FIELD_DEFS::edit (void);
PUBLIC SSTRING *FIELD_DEFS::getdefault (const char *sid);
PUBLIC void FIELD_DEFS::setupdia (DIALOG&dia);
/* groupadmin.cc 11/06/2001 08.56.12 */
/* help.cc 23/09/1999 20.59.42 */
/* internal.cc 19/08/2002 12.39.30 */
/* ldap_comng.cc 25/01/2001 02.26.20 */
PUBLIC USERINFO_COMNG::USERINFO_COMNG (DICTIONARY&_dict);
PUBLIC USERINFO_COMNG::~USERINFO_COMNG (void);
PUBLIC void USERINFO_COMNG::setupdia (DIALOG&dia);
PUBLIC int USERINFO_COMNG::save (PRIVILEGE *priv);
PUBLIC int USERINFO_COMNG::validate (DIALOG&, int &nof);
PUBLIC int USERINFO_COMNG::deluser (PRIVILEGE *);
/* ldap_db.cc 19/08/2002 10.35.26 */
PUBLIC LDAPDB::LDAPDB (void);
PUBLIC LDAPDB::LDAPDB (const char *dbname);
PUBLIC int LDAPDB::init (const char *dbname);
PUBLIC int LDAPDB::read (const char *dbname);
PUBLIC int LDAPDB::export_ldif (void);
PUBLIC int LDAPDB::export_ldif (const char *profile_name);
PUBLIC int LDAPDB::create (void);
PUBLIC int LDAPDB::import_ldif (void);
PUBLIC void LDAPDB::config (const char *dbname);
PUBLIC void LDAPDB::menu (void);
/* ldap_object.cc 18/10/2002 00.03.30 */
PUBLIC SSTRINGS *TB_SSTRINGS::getitem (int no)const;
PUBLIC LDAPOBJECT::LDAPOBJECT (void);
PUBLIC LDAPOBJECT::LDAPOBJECT (const char *profile_name);
PUBLIC void LDAPOBJECT::init (void);
PUBLIC const char *LDAPOBJECT::gettmpfile (void)const;
PUBLIC LDAPOBJECT::~LDAPOBJECT (void);
PUBLIC int LDAPOBJECT::reset (void);
PUBLIC int LDAPOBJECT::reset_data (void);
PUBLIC int LDAPOBJECT::command (const char *command, SSTRINGS&resmsg);
PUBLIC int LDAPOBJECT::add (void);
PUBLIC int LDAPOBJECT::modify (void);
PUBLIC int LDAPOBJECT::export_ldif (const char *path, bool append);
PUBLIC int LDAPOBJECT::export_ldif (const char *path);
PUBLIC int LDAPOBJECT::del (void);
PUBLIC char LDAPOBJECT::exist (const char *dn);
PUBLIC int LDAPOBJECT::search (void);
PUBLIC int LDAPOBJECT::search_list (SSTRINGS&lst);
PUBLIC int LDAPOBJECT::search_list_val (SSTRINGS&lst,
	 const char *key);
PUBLIC int LDAPOBJECT::search_list_vals (SSTRINGS&lst,
	 const char *key,
	 const char *at_name[]);
PUBLIC int LDAPOBJECT::search_list_vals (TB_SSTRINGS&lst,
	 const char *key,
	 const char *at_name[]);
PUBLIC int LDAPOBJECT::dn_set (const char *val);
PUBLIC int LDAPOBJECT::at_list (SSTRINGS&lst);
PUBLIC const char *LDAPOBJECT::at_get (const char *name);
PUBLIC const char *LDAPOBJECT::at_get (const char *name, int k);
PUBLIC int LDAPOBJECT::at_getall (const char *name, SSTRINGS&lst);
PUBLIC const char *LDAPOBJECT::at_getname (int num);
PUBLIC const char *LDAPOBJECT::at_getval (int num);
PUBLIC int LDAPOBJECT::at_set (const char *name, const char *val);
PUBLIC int LDAPOBJECT::at_set (const char *name, int val);
PUBLIC int LDAPOBJECT::at_add (const char *name, const char *val);
PUBLIC int LDAPOBJECT::at_add (const char *name, int val);
PUBLIC int LDAPOBJECT::at_del (const char *name);
PUBLIC int LDAPOBJECT::oc_list (SSTRINGS&lst);
PUBLIC int LDAPOBJECT::oc_add (const char *val);
PUBLIC int LDAPOBJECT::oc_del (const char *name);
PUBLIC const char *LDAPOBJECT::oc_getval (int num);
PUBLIC int LDAPOBJECT::oc_exist (const char *name);
PUBLIC SSTRING *LDAPOBJECT::locateassign (const char *key);
PUBLIC SSTRING *LDAPOBJECT::locateassign (const char *key, int k);
PUBLIC int LDAPOBJECT::locate (const char *key, SSTRINGS&lst);
PUBLIC int LDAPOBJECT::ldif_splitline (const char *ldif,
	 char *name,
	 char *val);
PUBLIC int LDAPOBJECT::load_profile (const char *profile_name);
PUBLIC int LDAPOBJECT::set_password (const char *username,
	 const char *password);
PUBLIC int LDAPOBJECT::export_confdb (CONFDB *c_data);
PUBLIC int LDAPOBJECT::import_confdb (CONFDB *c_data);
PUBLIC int LDAPOBJECT::get_free_uid (void);
PUBLIC int LDAPOBJECT::get_free_gid (void);
/* ldap_profile.cc 19/08/2002 12.25.56 */
PUBLIC LDAPPROFILE::LDAPPROFILE (void);
PUBLIC void LDAPPROFILE::default_dialog (void);
/* ldap_utils.cc 07/09/2001 20.11.06 */
/* ldapapi.cc 20/09/1999 10.56.22 */
/* ldapclient.cc 19/08/2002 12.15.20 */
/* ldapconf.cc 17/10/2002 23.58.36 */
PUBLIC MODULE_ldapconf::MODULE_ldapconf (void);
PUBLIC void MODULE_ldapconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_ldapconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_ldapconf::dohtml (const char *key);
PUBLIC void MODULE_ldapconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_ldapconf::execmain (int argc,
	 char *argv[],
	 bool sa);
PUBLIC int MODULE_ldapconf::message (const char *msg,
	 int argc,
	 const char *argv[]);
/* ldapconf_setup.cc 29/08/2002 11.38.02 */
/* ldapguru.tlcc 18/10/2002 00.14.20 */
/* ldapnss.cc 29/08/2002 12.44.22 */
/* ldapstatus.cc 01/03/2001 23.18.08 */
/* loghandler.cc 02/03/2001 09.54.40 */
/* menus.cc 01/03/2001 23.00.12 */
/* nssconf.cc 21/09/1999 16.46.36 */
/* openldap.cc 25/04/2002 13.11.30 */
/* pamconf.cc 25/04/2002 13.11.36 */
/* posix.tlcc 18/10/2002 00.14.20 */
/* profile.cc 19/08/2002 12.11.32 */
/* profiles.cc 22/01/2001 00.42.14 */
PUBLIC PROFILE::PROFILE (void);
PUBLIC PROFILE::~PROFILE (void);
PUBLIC void PROFILE::init (void);
PUBLIC void PROFILE::reset (void);
PUBLIC int PROFILE::setfile (const char *path);
PUBLIC PROFILES::PROFILES (void);
PUBLIC PROFILES::~PROFILES (void);
PUBLIC PROFILES::PROFILES (const char *path);
PUBLIC PROFILES::PROFILES (const char *path, const char *id);
PUBLIC void PROFILES::reset (void);
PUBLIC int PROFILES::get_list (SSTRINGS&lst);
PUBLIC int PROFILES::add (const char *id);
PUBLIC int PROFILES::add (CONFDB *db);
PUBLIC int PROFILES::del (void);
PUBLIC int PROFILES::setpath (const char *id);
PUBLIC int PROFILES::use (const char *id);
PUBLIC CONFDB *PROFILES::get (const char *id);
PUBLIC int PROFILES::dia_list (DIALOG&dia, SSTRINGS&tb);
PUBLIC int PROFILES::dia_select (void);
PUBLIC int PROFILES::dia_admin (void);
PUBLIC void PROFILES::setup_priv (PRIVILEGES&priv_tb,
	 const char *section);
/* user2ldif.tlcc 18/10/2002 00.14.20 */
/* useradmin.cc 26/08/2002 16.54.52 */

==> linuxconf-ldapconf-0.23.src.tar.gz: linuxconf-ldapconf-0.23/ldapconf.pm <==
/* _dict.cc 02/07/1999 14.11.24 */
/* browse.tlcc 01/05/2003 01.07.14 */
/* fields.cc 06/02/2003 14.41.14 */
PUBLIC FIELD_DEF::FIELD_DEF (void);
PUBLIC int FIELD_DEF::edit (void);
PUBLIC void FIELD_DEF::loadval (CONFDB *c_data, const char *key);
PUBLIC void FIELD_DEF::saveval (CONFDB&c_data, const char *key);
PUBLIC void FIELD_DEF::saveval (SSTRING_KEYS&c_data);
PUBLIC void FIELD_DEF::delval (CONFDB&c_data, const char *key);
PUBLIC FIELD_DEF *FIELD_DEFS::getitem (int no)const;
PUBLIC void FIELD_DEFS::loadval (CONFDB *c_data, const char *key);
PUBLIC void FIELD_DEFS::saveval (CONFDB&c_data, const char *key);
PUBLIC void FIELD_DEFS::saveval (SSTRING_KEYS&c_data);
PUBLIC void FIELD_DEFS::delval (CONFDB&c_data, const char *key);
PUBLIC FIELD_DEFS::FIELD_DEFS (void);
PUBLIC FIELD_DEFS::FIELD_DEFS (CONFDB *formconfig);
PUBLIC FIELD_DEFS::FIELD_DEFS (CONFIG_FILE *formfile);
PUBLIC FIELD_DEFS::FIELD_DEFS (const char *filename);
PUBLIC int FIELD_DEFS::read (void);
PUBLIC int FIELD_DEFS::write (void);
PUBLIC int FIELD_DEFS::edit (void);
PUBLIC SSTRING *FIELD_DEFS::getdefault (const char *sid);
PUBLIC void FIELD_DEFS::setupdia (DIALOG&dia);
/* groupadmin.cc 11/06/2001 08.56.12 */
/* help.cc 23/09/1999 20.59.42 */
/* internal.cc 06/02/2003 19.51.40 */
/* ldap_comng.cc 01/05/2003 01.06.04 */
PUBLIC USERINFO_COMNG::USERINFO_COMNG (DICTIONARY&_dict);
PUBLIC USERINFO_COMNG::~USERINFO_COMNG (void);
PUBLIC void USERINFO_COMNG::setupdia (DIALOG&dia);
PUBLIC int USERINFO_COMNG::save (PRIVILEGE *priv);
PRIVATE void USERINFO_COMNG::updatetb (void);
PUBLIC int USERINFO_COMNG::validate (DIALOG&, int &nof);
PUBLIC int USERINFO_COMNG::deluser (PRIVILEGE *);
/* ldap_db.cc 19/08/2002 10.35.26 */
PUBLIC LDAPDB::LDAPDB (void);
PUBLIC LDAPDB::LDAPDB (const char *dbname);
PUBLIC int LDAPDB::init (const char *dbname);
PUBLIC int LDAPDB::read (const char *dbname);
PUBLIC int LDAPDB::export_ldif (void);
PUBLIC int LDAPDB::export_ldif (const char *profile_name);
PUBLIC int LDAPDB::create (void);
PUBLIC int LDAPDB::import_ldif (void);
PUBLIC void LDAPDB::config (const char *dbname);
PUBLIC void LDAPDB::menu (void);
/* ldap_object.cc 10/04/2003 16.40.28 */
PUBLIC SSTRINGS *TB_SSTRINGS::getitem (int no)const;
PUBLIC LDAPOBJECT::LDAPOBJECT (void);
PUBLIC LDAPOBJECT::LDAPOBJECT (const char *profile_name);
PUBLIC void LDAPOBJECT::init (void);
PUBLIC const char *LDAPOBJECT::gettmpfile (void)const;
PUBLIC LDAPOBJECT::~LDAPOBJECT (void);
PUBLIC int LDAPOBJECT::reset (void);
PUBLIC int LDAPOBJECT::reset_data (void);
PUBLIC int LDAPOBJECT::command (const char *command, SSTRINGS&resmsg);
PUBLIC int LDAPOBJECT::add (void);
PUBLIC int LDAPOBJECT::modify (void);
PUBLIC int LDAPOBJECT::export_ldif (const char *path, bool append);
PUBLIC int LDAPOBJECT::export_ldif (const char *path);
PUBLIC int LDAPOBJECT::del (void);
PUBLIC char LDAPOBJECT::exist (const char *dn);
PUBLIC int LDAPOBJECT::search (void);
PUBLIC int LDAPOBJECT::search_list (SSTRINGS&lst);
PUBLIC int LDAPOBJECT::search_list_val (SSTRINGS&lst,
	 const char *key);
PUBLIC int LDAPOBJECT::search_list_vals (SSTRINGS&lst,
	 const char *key,
	 const char *at_name[]);
PUBLIC int LDAPOBJECT::search_list_vals (TB_SSTRINGS&lst,
	 const char *key,
	 const char *at_name[]);
PUBLIC int LDAPOBJECT::dn_set (const char *val);
PUBLIC int LDAPOBJECT::at_list (SSTRINGS&lst);
PUBLIC const char *LDAPOBJECT::at_get (const char *name);
PUBLIC const char *LDAPOBJECT::at_get (const char *name, int k);
PUBLIC int LDAPOBJECT::at_getall (const char *name, SSTRINGS&lst);
PUBLIC const char *LDAPOBJECT::at_getname (int num);
PUBLIC const char *LDAPOBJECT::at_getval (int num);
PUBLIC int LDAPOBJECT::at_set (const char *name, const char *val);
PUBLIC int LDAPOBJECT::at_set (const char *name, int val);
PUBLIC int LDAPOBJECT::at_add (const char *name, const char *val);
PUBLIC int LDAPOBJECT::at_add (const char *name, int val);
PUBLIC int LDAPOBJECT::at_del (const char *name);
PUBLIC int LDAPOBJECT::oc_list (SSTRINGS&lst);
PUBLIC int LDAPOBJECT::oc_add (const char *val);
PUBLIC int LDAPOBJECT::oc_del (const char *name);
PUBLIC const char *LDAPOBJECT::oc_getval (int num);
PUBLIC int LDAPOBJECT::oc_exist (const char *name);
PUBLIC SSTRING *LDAPOBJECT::locateassign (const char *key);
PUBLIC SSTRING *LDAPOBJECT::locateassign (const char *key, int k);
PUBLIC int LDAPOBJECT::locate (const char *key, SSTRINGS&lst);
PUBLIC int LDAPOBJECT::ldif_splitline (const char *ldif,
	 char *name,
	 char *val);
PUBLIC int LDAPOBJECT::load_profile (const char *profile_name);
PUBLIC int LDAPOBJECT::set_password (const char *username,
	 const char *password);
PUBLIC int LDAPOBJECT::export_confdb (CONFDB&c_data);
PUBLIC int LDAPOBJECT::import_confdb (const CONFDB&c_data, bool reset);
PUBLIC int LDAPOBJECT::import_keys (const SSTRING_KEYS&c_data,
	 bool reset);
PUBLIC int LDAPOBJECT::get_free_uid (void);
PUBLIC int LDAPOBJECT::get_free_gid (void);
/* ldap_profile.cc 10/04/2003 16.33.34 */
PUBLIC LDAPPROFILE::LDAPPROFILE (void);
PUBLIC void LDAPPROFILE::default_dialog (void);
/* ldap_utils.cc 07/09/2001 20.11.06 */
/* ldapapi.cc 20/09/1999 10.56.22 */
/* ldapclient.cc 19/08/2002 12.15.20 */
/* ldapconf.cc 05/02/2003 22.04.40 */
PUBLIC MODULE_ldapconf::MODULE_ldapconf (void);
PUBLIC void MODULE_ldapconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_ldapconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_ldapconf::dohtml (const char *key);
PUBLIC void MODULE_ldapconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_ldapconf::execmain (int argc,
	 char *argv[],
	 bool sa);
PUBLIC int MODULE_ldapconf::message (const char *msg,
	 int argc,
	 const char *argv[]);
/* ldapconf_setup.cc 17/02/2003 11.45.36 */
/* ldapgetcmd.tlcc 01/05/2003 01.07.14 */
/* ldapguru.tlcc 01/05/2003 01.07.14 */
/* ldapnss.cc 13/02/2003 17.36.02 */
/* ldapsendcmd.tlcc 01/05/2003 01.07.14 */
/* ldapstatus.cc 01/03/2001 23.18.08 */
/* loghandler.cc 02/03/2001 09.54.40 */
/* menus.cc 01/03/2001 23.00.12 */
/* misc.tlcc 01/05/2003 01.07.14 */
/* nssconf.cc 21/09/1999 16.46.36 */
/* openldap.cc 13/02/2003 17.35.14 */
/* pamconf.cc 25/04/2002 13.11.36 */
/* posix.tlcc 01/05/2003 01.07.14 */
/* profile.cc 10/04/2003 16.41.22 */
/* profiles.cc 22/01/2001 00.42.14 */
PUBLIC PROFILE::PROFILE (void);
PUBLIC PROFILE::~PROFILE (void);
PUBLIC void PROFILE::init (void);
PUBLIC void PROFILE::reset (void);
PUBLIC int PROFILE::setfile (const char *path);
PUBLIC PROFILES::PROFILES (void);
PUBLIC PROFILES::~PROFILES (void);
PUBLIC PROFILES::PROFILES (const char *path);
PUBLIC PROFILES::PROFILES (const char *path, const char *id);
PUBLIC void PROFILES::reset (void);
PUBLIC int PROFILES::get_list (SSTRINGS&lst);
PUBLIC int PROFILES::add (const char *id);
PUBLIC int PROFILES::add (CONFDB *db);
PUBLIC int PROFILES::del (void);
PUBLIC int PROFILES::setpath (const char *id);
PUBLIC int PROFILES::use (const char *id);
PUBLIC CONFDB *PROFILES::get (const char *id);
PUBLIC int PROFILES::dia_list (DIALOG&dia, SSTRINGS&tb);
PUBLIC int PROFILES::dia_select (void);
PUBLIC int PROFILES::dia_admin (void);
PUBLIC void PROFILES::setup_priv (PRIVILEGES&priv_tb,
	 const char *section);
/* user2ldif.tlcc 01/05/2003 01.07.14 */
/* useradmin.cc 01/05/2003 00.48.26 */
